pitchtools.PitchObjectSegment
=============================

.. abjad-lineage:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment

.. autoclass:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.count
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.index
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__add__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__contains__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__getitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__getslice__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__iter__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__len__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__mul__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__rmul__
   :noindex:
